Changelog
=========

v0.5 (2021-03-31)
-----------------

- Adopt https://github.com/nexB/skeleton
- Support Python 3 only, drop Python 2 support
- Support both PyYAML 5.x only
- Drop travis for Azure pipelines


v0.4 (2019-04-10)
-----------------

- Dump nulls correctly
- Fix CI on Travis
- Attempt to support PyYAML 5.x partially


v0.3 (2019-04-07)
-----------------

- Use OrderedDict to keep ordering of mappings


v0.1 (2018-11-17)
-----------------

- Initial release based on code originally used in ScanCode toolkit.
